#ifndef QGPCORESTAT_HEADERS
#define QGPCORESTAT_HEADERS

// All headers of QGpCoreStat library

#include "GaussianMixtureDistribution.h"
#include "GaussianMixtureEM.h"
#include "GaussianMixtureLikelihood.h"
#include "GaussianMixtureParameters.h"
#include "Histogram.h"
#include "Histogram2D.h"
#include "HistogramInversion.h"
#include "HistogramReader.h"
#include "MultivariateHistogram.h"
#include "QGpCoreStatDLLExport.h"
#include "SampleClassificationParameters.h"
#include "SampleFilter.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpCoreStat;
#endif

#endif // QGPCORESTAT_HEADERS
